@@ -6,5 +6,5 @@ class ComplexityResult(Result):
 
     kind = "correctness"
 
-    def __init__(self, passing: bool, complete: bool = True, error: Error = None, **details):
+    def __init__(self, passing: bool, complete: bool = True, error: Error = None, details: dict = None):
         super().__init__(complete=complete, passing=passing, error=error, details=details)
